@@ -5,13 +5,13 @@ var b = types.builders;
 var path = require("path");
 var fs = require("fs");
 var parse = require("esprima").parse;
-var Path = require("../lib/path");
-var NodePath = require("../lib/node-path");
-var PathVisitor = require("../lib/path-visitor");
-var builtin = types.builtInTypes
+var Path = types.Path;
+var NodePath = types.NodePath;
+var PathVisitor = types.PathVisitor;
+var builtin = types.builtInTypes;
 var isRegExp = builtin.RegExp;
 var isString = builtin.string;
-var rawTypes = require("../lib/types");
+var rawTypes = types.use(require("../lib/types"));
 
 var hasOwn = Object.prototype.hasOwnProperty;
 
@@ -64,7 +64,7 @@ describe("isSupertypeOf", function() {
 
 describe("supertype lookup", function() {
     it("should resolve the most precise supertypes", function() {
-        var table = require("../lib/types").computeSupertypeLookupTable({
+        var table = types.use(require("../lib/types")).computeSupertypeLookupTable({
             Function: true,
             Declaration: true,
             ArrowFunctionExpression: true,
@@ -2133,3 +2133,61 @@ describe("RegExpLiteral nodes", function() {
         assert.strictEqual(n.Literal.check(regExpLiteral, true), false);
     });
 });
+
+
+describe("MemberExpression", function() {
+    it("should set computed flag to false by default", function(){
+        var memberExpression = b.memberExpression(
+            b.identifier('foo'),
+            b.identifier('bar')
+        )
+
+        assert.strictEqual(memberExpression.computed, false)
+    });
+
+    it("should not set computed to true if property is a callExpression", function(){
+        var memberExpression = b.memberExpression(
+            b.identifier('foo'),
+            b.callExpression(b.identifier('bar'), [])
+        )
+
+        assert.strictEqual(memberExpression.computed, false)
+    });
+
+    it("should set computed flag to true if property is a literal", function(){
+        var memberExpression = b.memberExpression(
+            b.identifier('foo'),
+            b.literal('bar')
+        )
+
+        assert.strictEqual(memberExpression.computed, true)
+    });
+
+    it("should set computed flag to true if property is a memberExpression", function(){
+        var memberExpression = b.memberExpression(
+            b.identifier('foo'),
+            b.memberExpression(b.identifier('foo'), b.literal('bar'))
+        )
+
+        assert.strictEqual(memberExpression.computed, true)
+    });
+
+    it("should set computed flag to true if property is a binaryExpression", function(){
+        var memberExpression = b.memberExpression(
+            b.identifier('foo'),
+            b.memberExpression(b.identifier('foo'), b.literal('bar'))
+        )
+
+        assert.strictEqual(memberExpression.computed, true)
+    });
+
+    it("should override computed value when passed as a third argument to the builder", function(){
+        var memberExpression = b.memberExpression(
+            b.identifier('foo'),
+            b.callExpression(b.identifier('bar'), []),
+            true
+        )
+
+        assert.strictEqual(memberExpression.computed, true);
+    });
+});
